BoundingBox

#[repr(C)]
pub struct BoundingBox { pub top_left: Point, pub bottom_right: Point, }
A bounding box in 2D space. This is the result of “drawing” operations on our canvas, and what the server reports back to the client. These bounds are sufficient to contain all of the lines (inclusive) on a canvas at a given time.

Fields

top_left: Pointbottom_right: Point