#[repr(C)]pub struct BoundingBox {
pub top_left: Point,
pub bottom_right: Point,
}Expand description
A bounding box in 2D space. This is the result of “drawing” operations on our canvas, and what the server reports back to the client. These bounds are sufficient to contain all of the lines (inclusive) on a canvas at a given time.
Fields
top_left: Pointbottom_right: PointTrait Implementations
Sourceimpl Clone for BoundingBox
impl Clone for BoundingBox
Sourcefn clone(&self) -> BoundingBox
fn clone(&self) -> BoundingBox
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<BoundingBox> for BoundingBox
impl CompatFrom<BoundingBox> for BoundingBox
Sourcefn compat_from(value: BoundingBox) -> BoundingBox
fn compat_from(value: BoundingBox) -> BoundingBox
Converts
value into a value of this type.Sourceimpl Debug for BoundingBox
impl Debug for BoundingBox
Sourceimpl<'a, ___E> Encode<BoundingBox, ___E> for &'a BoundingBoxwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<BoundingBox, ___E> for &'a BoundingBoxwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BoundingBox>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BoundingBox>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<BoundingBox, ___E> for BoundingBoxwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<BoundingBox, ___E> for BoundingBoxwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<BoundingBox, BoundingBox>
const COPY_OPTIMIZATION: CopyOptimization<BoundingBox, BoundingBox>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BoundingBox>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BoundingBox>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, BoundingBox>, ___E> for &'a BoundingBox
impl<'a, ___E> EncodeOption<Box<'static, BoundingBox>, ___E> for &'a BoundingBox
Sourcefn encode_option(
this: Option<&'a BoundingBox>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BoundingBox>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a BoundingBox>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BoundingBox>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, BoundingBox>, ___E> for BoundingBox
impl<___E> EncodeOption<Box<'static, BoundingBox>, ___E> for BoundingBox
Sourcefn encode_option(
this: Option<BoundingBox>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BoundingBox>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<BoundingBox>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BoundingBox>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<BoundingBox> for BoundingBox
impl FromWire<BoundingBox> for BoundingBox
Sourceconst COPY_OPTIMIZATION: CopyOptimization<BoundingBox, BoundingBox>
const COPY_OPTIMIZATION: CopyOptimization<BoundingBox, BoundingBox>
Sourcefn from_wire(wire: BoundingBox) -> BoundingBox
fn from_wire(wire: BoundingBox) -> BoundingBox
Converts the given owned value to this type.
Sourceimpl FromWireRef<BoundingBox> for BoundingBox
impl FromWireRef<BoundingBox> for BoundingBox
Sourcefn from_wire_ref(wire: &BoundingBox) -> BoundingBox
fn from_wire_ref(wire: &BoundingBox) -> BoundingBox
Converts the given reference to this type.
Sourceimpl Hash for BoundingBox
impl Hash for BoundingBox
Sourceimpl Ord for BoundingBox
impl Ord for BoundingBox
Sourcefn cmp(&self, other: &BoundingBox) -> Ordering
fn cmp(&self, other: &BoundingBox) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BoundingBox
impl PartialEq for BoundingBox
Sourceimpl PartialOrd for BoundingBox
impl PartialOrd for BoundingBox
impl Copy for BoundingBox
impl Eq for BoundingBox
impl StructuralPartialEq for BoundingBox